<?php

use App\Http\Controllers\CategoryController;
use App\Http\Controllers\KategoriController;
use App\Http\Controllers\MenuController;
use App\Http\Controllers\PostController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\RefCategoryController;
use App\Http\Controllers\RefSubCategoryController;
use App\Http\Controllers\SubCategoryController;
use App\Http\Controllers\SubKategoriController;
use Illuminate\Foundation\Application;
use Illuminate\Support\Facades\Route;
use Inertia\Inertia;
use Illuminate\Http\Response;

Route::get('/', function () {
    return Inertia::render('welcome', [
        'canLogin' => Route::has('login'),
        'canRegister' => Route::has('register'),
        'laravelVersion' => Application::VERSION,
        'phpVersion' => PHP_VERSION,
    ]);
});

// Route::get('/404', function () {
//     return Inertia::render('404');
// });

Route::fallback(function () {
    return Inertia::render('404');
});

Route::get('/pengumuman', function () {
    return Inertia::render('Pengumuman');
});

Route::get('/test', function () {
    return Inertia::render('Test');
});

Route::get('/undangan', function () {
    return Inertia::render('Undangan');
});

Route::get('/peraturan', function () {
    return Inertia::render('Peraturan');
});

// Dashboard Route

Route::get('/dashboard', function () {
    return Inertia::render('dashboard');
})->middleware(['auth'])->name('dashboard');

Route::middleware(['auth'])->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');
});

Route::middleware(['auth'])->prefix('admin')->group(function () {
    Route::get('/kategori', [KategoriController::class, 'index'])->name('admin.kategori.index');
    Route::post('/kategori', [KategoriController::class, 'store'])->name('admin.kategori.store');
    Route::put('/kategori/{kategori}', [KategoriController::class, 'update'])->name('admin.kategori.update');
    Route::delete('/kategori/{kategori}', [KategoriController::class, 'destroy'])->name('admin.kategori.destroy');
});

Route::middleware(['auth'])->prefix('admin')->group(function () {
    Route::get('/subkategori', [SubKategoriController::class, 'index'])->name('admin.subkategori.index');
    Route::post('/subkategori', [SubKategoriController::class, 'store'])->name('admin.subkategori.store');
    Route::put('/subkategori/{subkategori}', [SubKategoriController::class, 'update'])->name('admin.subkategori.update');
    Route::delete('/subkategori/{subkategori}', [SubKategoriController::class, 'destroy'])->name('admin.subkategori.destroy');
});

Route::middleware(['auth'])->prefix('admin')->group(function () {
    Route::get('/post', [PostController::class, 'index'])->name('admin.post.index');
    Route::get('/post/add', [PostController::class, 'create'])->name('admin.post.create');
    Route::post('/post', [PostController::class, 'store'])->name('admin.post.store');
    Route::get('/post/edit/{post}', [PostController::class, 'edit'])->name('admin.post.edit');
    Route::put('/post/{post}', [PostController::class, 'update'])->name('admin.post.update');
    Route::delete('/post/{post}', [PostController::class, 'destroy'])->name('admin.post.destroy');
});




require __DIR__.'/auth.php';
